==> sigaddons-7.0.21.12.14.tar.gz: sigaddons-7.0.21.12.14/sigaddons/supervisor_producao_comanda/control/dispositivo.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2009 All Rights Reserved. Luiz Fernando Maciel Franca
#                    www.siginformatica.com.br luiz@siginformatica.com.br
#
##############################################################################

from openerp.osv import osv
from openerp.tools.translate import _
from SigUtils.crypto import decrypt
import xmlrpclib, socket
import subprocess
import base64
import os
import requests
import json


pkey_sig = """-----BEGIN RSA PRIVATE KEY-----
MIICXQIBAAKBgQDNlPEHacb00nIQ7rrZ3U4kL9QAU+vvXbLLHGR45+7zYb2cBE2s
qmnUpSgf2Jp2HL0Dz/paqxpB4pOxU6kEcDs1QOlTjt5rTsKKiw6Of7g1MsrIEQCz
tF+u8xXyl93JB0M2QBQ4PGVQQsHxyd+jdWHCOj/YpJCA/8rJUbhiVoRaQwIDAQAB
AoGBAMnIdUO3eUb4AGnKSLBq3bX7E/U2ag/KQiHGPn/F9u4Ac6FdP/hIVBQZ/2Yy
rnlb/9JsIuk3pFAi2qBk4zKuDg2V57DY+h31SLVjENZHD3M0MGonFzu1uay+s/m0
X0mMbueNXuWAAYkoAPL/wEjP/ciJkqfCUiOJADcf7PJhXfhxAkEA9F1mdw+z+GPu
tHabZ2WJJSb7JnZtAskG/spFye6UUUw53tC7mLZ7Ye3dESa3l9jtRfC4CSKbNJhX
9JyTkzcabQJBANdezxdVg4gbBbdBm6cf59aT7Y1KIrqkDtQpENBJVMXJUIa2CTEc
QvGE3UwOA37zLRFtkSZk0w1590wC7NkwWW8CQBmr+kjF0I1myjwRPdBF/Xt2tenb
hSZGwkJgM6a8Nr63uFitKxgnC51FJPVZUO5V7s9rM5paFV4YJx1ema5cmp0CQQCo
gwgqS8CEqBAK2Qy+8RnnLQt7t3wA6QipPBBpyFbKAsA9BwWeJWzDqJ+2OGjH1eF3
d3FQxybTrpCuKsPDFC+FAkALWOoMA+liEcsz/n7BardljL0BRDuqMaS2iuQ/RTAH
34xfgVdzAN8XNLA+FOAWMxyDxP1vfoa6SwUsTZsdebGa
-----END RSA PRIVATE KEY-----"""

class supervisor_producao_comanda_dispositivo(osv.Model):

    _inherit = 'supervisor.producao.comanda.dispositivo'

    def get_cnpj(self, cr, uid, context=None):
        context = context and context.copy() or {}
        obj_config = self.pool.get('supervisor.cfg.configuracao')
        config_ids = obj_config.search(cr, uid,[], context=context)
        dados_config = obj_config.read(cr, uid, config_ids, ['supcfc_cnpj'], context)
        return dados_config and dados_config[0].get('supcfc_cnpj') or ''

    def spcdis_check_licenca(self, cr, uid, vals, context=None):
        context = context and context.copy() or {}
        # verifica a licenca do ERP primeiro
        self.pool.get('valida.pendencias').valpen_verificar_licenca_ativa(cr, uid, context)
        nro_serie = vals.get('serial')
        modelo = vals.get('model')
        marca = vals.get('brand')
        cnpj = vals.get('cnpj')
        args = [('spcdis_nro_serie', '=', nro_serie),
                ('spcdis_modelo', '=', modelo),
                ('spcdis_marca', '=', marca),
                ('spcdis_cnpj', '=', cnpj)]
        dispositivo_ids = self.search(cr, uid, args, context=context)
        if not dispositivo_ids:
            vals_disp = {'spcdis_nro_serie': nro_serie,
                         'spcdis_modelo': modelo,
                         'spcdis_marca': marca,
                         'spcdis_cnpj': cnpj}
            dispositivo_ids = [self.create(cr, uid, vals_disp, context=context)]
            self.spcdis_gerar_licenca(cr, uid, dispositivo_ids, context)

        licenca = self.read(cr, uid, dispositivo_ids[0], ['spcdis_licenca'],
                                       context=context).get('spcdis_licenca')
        try:
            licenca = decrypt(licenca, pkey_sig).split('#|#')
        except:
            return False

        if len(licenca) != 3 or modelo != licenca[0] or marca != licenca[1] or \
                nro_serie != licenca[2]:
            return False

        return True

    def spcdis_gerar_licenca(self, cr, uid, ids, context=None):
        context = context and context.copy() or {}
        obj_config_parameter = self.pool.get('ir.config_parameter')
        campos = ['spcdis_marca', 'spcdis_modelo', 'spcdis_nro_serie', 'spcdis_cnpj']
        dados_dispositivo = self.read(cr, uid, ids[0], campos, context=context)
        servidor = obj_config_parameter.get_sig_server(cr, uid, context=context).split(',')
        try:
            host = servidor[0]
            db = servidor[1]
            porta = servidor[2]
            user = servidor[3]
            senha = servidor[4]
            res = requests.post('http://%s:%s/contrecf/get_mobile_licenca' % (host, porta),
                                auth=(user, senha),
                                data={'db': db,
                                      'senha': senha,
                                      'user': user,
                                      'url': host,
                                      'port': porta,
                                      'marca': dados_dispositivo.pop('spcdis_marca'),
                                      'modelo': dados_dispositivo.pop('spcdis_modelo'),
                                      'nro_serie': dados_dispositivo.pop('spcdis_nro_serie'),
                                      'cnpj': dados_dispositivo.pop('spcdis_cnpj'),
                                      },
                                timeout=10000)
            res = json.loads(res.content)
            if res.get('codigo') != '00':
                raise osv.except_osv(_('Atencao!'), res.get('mensagem'))
            # sock_common = xmlrpclib.ServerProxy('http://' + host + ':' + str(porta) +
            #                                     '/xmlrpc/common')
            # socket.setdefaulttimeout(5)
            # uid_ = sock_common.login(db, user, senha)
            # sock = xmlrpclib.ServerProxy('http://' + host + ':' + str(porta) + '/xmlrpc/object')
            # res = sock.execute(db, uid_, senha, 'contrecf.mobile', 'get_mobile_licenca',
            #                    dados_dispositivo, context)

        except Exception as e:
            raise osv.except_osv(_('Atencao!'), _('Erro comunicando com servidor da SIG!:\n%s') % e)

        res = res.get('retorno')[0]
        if not res[0]:
            raise osv.except_osv(_('Atencao!'), res[1])

        licenca = base64.decodestring(res[1])
        vals = {'spcdis_licenca': licenca}
        self.write(cr, uid, ids, vals, context=context)
        return True

    def spcdis_button_gerar_licenca(self, cr, uid, ids, context=None):
        context = context and context.copy() or {}
        return self.spcdis_gerar_licenca(cr, uid, ids, context)

    def spcdis_imprimir(self, cr, uid, impressora, texto, arquivo, context=None):
        context = context and context.copy() or {}
        obj_cmd = self.pool.get('supervisor.cad.comandos.impressoras')
        imp_ids = obj_cmd.search(cr, uid, [('state', '=', '2')], context=context)
        if not imp_ids:
            raise osv.except_osv(_('Atencao!'), _('Sem impressora ativa no cadastro de impresoras!'))

        cmd = obj_cmd.read(cr, uid, imp_ids[0], [], context) or ''
        ini_negrito = '%s' % cmd.get('supcci_negrito_liga')
        fim_negrito = '%s' % cmd.get('supcci_negrito_desliga')
        fonte_i = cmd.get('supcci_fonte_liga')
        fonte_f = cmd.get('supcci_fonte_desliga')
        ini_sub = cmd.get('supcci_sub_liga')
        fim_sub = cmd.get('supcci_sub_desliga')
        corta_papel = '\n' + cmd.get('supcci_corta_papel')
        arquivo = '/tmp/' + arquivo
        obj_cmd = self.pool.get('supervisor.cad.comandos.impressoras')
        imp_ids = obj_cmd.search(cr, uid, [('state', '=', '2')], context=context)
        if not imp_ids:
            raise osv.except_osv(('Atencao!'), ('Sem impressora ativa no cadastro de impresoras!'))

        parametros = self.pool.get('ir.config_parameter').get_param(cr, uid, 'supervisor.impressora.cozinha')
        if not parametros:
            self.pool.get('ir.config_parameter').set_param(cr, uid, 'supervisor.impressora.cozinha',
                                                           'USUARIO_UBUNTU;PORTA_DA_IMPRESSORA')
            raise osv.except_osv(('Atencao!'), ('Parametros de sistema da impressora nao configurados!'))
        try:
            parametros = parametros.split(';')
        except:
            raise osv.except_osv(('Atencao!'), ('Parametros de sistema da impressora estao incorretos!'))

        nome = obj_cmd.read(cr, uid, imp_ids[0], ['supcci_marca'], context).get('supcci_marca') or ''
        if nome.upper() in ('ELGIN'):
            corta_papel = '\n\n' + corta_papel

        texto = (cmd.get('supcci_espacamento_linha') or '') + texto
        file = open(arquivo, 'w')
        file.write(texto.format(b1=ini_negrito,
                                 b2=fim_negrito,
                                 s1=ini_sub,
                                 s2=fim_sub,
                                 f1=fonte_i,
                                 f2=fonte_f,
                                 corta=corta_papel).decode('string_escape'))
        file.close()
        try:
            if nome.upper() in ('ELGIN', 'EPSON'):
                os.system("echo %s | sudo -S chmod 776 %s; cat %s > %s" %
                          (parametros[0] or 'sig',
                           parametros[1],
                           arquivo,
                           parametros[1]))
            else:
                subprocess.call(["lp", "-o raw", "-n1", '-d%s' % impressora, arquivo])

        except Exception as e:
            return [0, '%s' % e]

        return [1, "Imprimiu"]

==> sigaddons-7.0.2310.2.tar.gz: sigaddons-7.0.2310.2/sigaddons/supervisor_producao_comanda/control/dispositivo.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2009 All Rights Reserved. Luiz Fernando Maciel Franca
#                    www.siginformatica.com.br luiz@siginformatica.com.br
#
##############################################################################

from openerp.osv import osv
from openerp.tools.translate import _
from SigUtils.crypto import decrypt
import xmlrpclib, socket
import subprocess
import base64
import os
import requests
import json


pkey_sig = """-----BEGIN RSA PRIVATE KEY-----
MIICXQIBAAKBgQDNlPEHacb00nIQ7rrZ3U4kL9QAU+vvXbLLHGR45+7zYb2cBE2s
qmnUpSgf2Jp2HL0Dz/paqxpB4pOxU6kEcDs1QOlTjt5rTsKKiw6Of7g1MsrIEQCz
tF+u8xXyl93JB0M2QBQ4PGVQQsHxyd+jdWHCOj/YpJCA/8rJUbhiVoRaQwIDAQAB
AoGBAMnIdUO3eUb4AGnKSLBq3bX7E/U2ag/KQiHGPn/F9u4Ac6FdP/hIVBQZ/2Yy
rnlb/9JsIuk3pFAi2qBk4zKuDg2V57DY+h31SLVjENZHD3M0MGonFzu1uay+s/m0
X0mMbueNXuWAAYkoAPL/wEjP/ciJkqfCUiOJADcf7PJhXfhxAkEA9F1mdw+z+GPu
tHabZ2WJJSb7JnZtAskG/spFye6UUUw53tC7mLZ7Ye3dESa3l9jtRfC4CSKbNJhX
9JyTkzcabQJBANdezxdVg4gbBbdBm6cf59aT7Y1KIrqkDtQpENBJVMXJUIa2CTEc
QvGE3UwOA37zLRFtkSZk0w1590wC7NkwWW8CQBmr+kjF0I1myjwRPdBF/Xt2tenb
hSZGwkJgM6a8Nr63uFitKxgnC51FJPVZUO5V7s9rM5paFV4YJx1ema5cmp0CQQCo
gwgqS8CEqBAK2Qy+8RnnLQt7t3wA6QipPBBpyFbKAsA9BwWeJWzDqJ+2OGjH1eF3
d3FQxybTrpCuKsPDFC+FAkALWOoMA+liEcsz/n7BardljL0BRDuqMaS2iuQ/RTAH
34xfgVdzAN8XNLA+FOAWMxyDxP1vfoa6SwUsTZsdebGa
-----END RSA PRIVATE KEY-----"""

class supervisor_producao_comanda_dispositivo(osv.Model):

    _inherit = 'supervisor.producao.comanda.dispositivo'

    def get_cnpj(self, cr, uid, context=None):
        context = context and context.copy() or {}
        obj_config = self.pool.get('supervisor.cfg.configuracao')
        config_ids = obj_config.search(cr, uid,[], context=context)
        dados_config = obj_config.read(cr, uid, config_ids, ['supcfc_cnpj'], context)
        return dados_config and dados_config[0].get('supcfc_cnpj') or ''

    def spcdis_check_licenca(self, cr, uid, vals, context=None):
        context = context and context.copy() or {}
        # verifica a licenca do ERP primeiro
        self.pool.get('valida.pendencias').valpen_verificar_licenca_ativa(cr, uid, context)
        nro_serie = vals.get('serial')
        modelo = vals.get('model')
        marca = vals.get('brand')
        cnpj = vals.get('cnpj')
        args = [('spcdis_nro_serie', '=', nro_serie),
                ('spcdis_modelo', '=', modelo),
                ('spcdis_marca', '=', marca),
                ('spcdis_cnpj', '=', cnpj)]
        dispositivo_ids = self.search(cr, uid, args, context=context)
        if not dispositivo_ids:
            vals_disp = {'spcdis_nro_serie': nro_serie,
                         'spcdis_modelo': modelo,
                         'spcdis_marca': marca,
                         'spcdis_cnpj': cnpj}
            dispositivo_ids = [self.create(cr, uid, vals_disp, context=context)]
            self.spcdis_gerar_licenca(cr, uid, dispositivo_ids, context)

        licenca = self.read(cr, uid, dispositivo_ids[0], ['spcdis_licenca'],
                                       context=context).get('spcdis_licenca')
        try:
            licenca = decrypt(licenca, pkey_sig).split('#|#')
        except:
            return False

        if len(licenca) != 3 or modelo != licenca[0] or marca != licenca[1] or \
                nro_serie != licenca[2]:
            return False

        return True

    def spcdis_gerar_licenca(self, cr, uid, ids, context=None):
        context = context and context.copy() or {}
        obj_config_parameter = self.pool.get('ir.config_parameter')
        campos = ['spcdis_marca', 'spcdis_modelo', 'spcdis_nro_serie', 'spcdis_cnpj']
        dados_dispositivo = self.read(cr, uid, ids[0], campos, context=context)
        servidor = obj_config_parameter.get_sig_server(cr, uid, context=context).split(',')
        try:
            host = servidor[0]
            db = servidor[1]
            porta = servidor[2]
            user = servidor[3]
            senha = servidor[4]
            res = requests.post('http://%s:%s/contrecf/get_mobile_licenca' % (host, porta),
                                auth=(user, senha),
                                data={'db': db,
                                      'senha': senha,
                                      'user': user,
                                      'url': host,
                                      'port': porta,
                                      'marca': dados_dispositivo.pop('spcdis_marca'),
                                      'modelo': dados_dispositivo.pop('spcdis_modelo'),
                                      'nro_serie': dados_dispositivo.pop('spcdis_nro_serie'),
                                      'cnpj': dados_dispositivo.pop('spcdis_cnpj'),
                                      },
                                timeout=10000)
            res = json.loads(res.content)
            if res.get('codigo') != '00':
                raise osv.except_osv(_('Atencao!'), res.get('mensagem'))
            # sock_common = xmlrpclib.ServerProxy('http://' + host + ':' + str(porta) +
            #                                     '/xmlrpc/common')
            # socket.setdefaulttimeout(5)
            # uid_ = sock_common.login(db, user, senha)
            # sock = xmlrpclib.ServerProxy('http://' + host + ':' + str(porta) + '/xmlrpc/object')
            # res = sock.execute(db, uid_, senha, 'contrecf.mobile', 'get_mobile_licenca',
            #                    dados_dispositivo, context)

        except Exception as e:
            raise osv.except_osv(_('Atencao!'), _('Erro comunicando com servidor da SIG!:\n%s') % e)

        res = res.get('retorno')[0]
        if not res[0]:
            raise osv.except_osv(_('Atencao!'), res[1])

        licenca = base64.decodestring(res[1])
        vals = {'spcdis_licenca': licenca}
        self.write(cr, uid, ids, vals, context=context)
        return True

    def spcdis_button_gerar_licenca(self, cr, uid, ids, context=None):
        context = context and context.copy() or {}
        return self.spcdis_gerar_licenca(cr, uid, ids, context)

    def spcdis_imprimir(self, cr, uid, vals_impressora, arquivo, context=None):
        context = context and context.copy() or {}
        texto = '\n'.join(vals_impressora.get('texto'))
        obj_cmd = self.pool.get('supervisor.cad.comandos.impressoras')
        imp_ids = obj_cmd.search(cr, uid, [('state', '=', '2')], context=context)
        if not imp_ids and not vals_impressora.get('comando_id'):
            raise osv.except_osv(_('Atencao!'), _('Sem impressora ativa no cadastro de impressoras!'))

        cmd = obj_cmd.read(cr, uid, vals_impressora.get('comando_id') or imp_ids[0], [], context) or ''
        ini_negrito = '%s' % cmd.get('supcci_negrito_liga')
        fim_negrito = '%s' % cmd.get('supcci_negrito_desliga')
        fonte_i = cmd.get('supcci_fonte_liga')
        fonte_f = cmd.get('supcci_fonte_desliga')
        ini_sub = cmd.get('supcci_sub_liga')
        fim_sub = cmd.get('supcci_sub_desliga')
        corta_papel = '\n' + cmd.get('supcci_corta_papel')
        arquivo = '/tmp/' + arquivo
        parametros = self.pool.get('ir.config_parameter').get_param(cr, uid, 'supervisor.impressora.cozinha')
        if not parametros and not vals_impressora.get('comando_id'):
            self.pool.get('ir.config_parameter').set_param(cr, uid, 'supervisor.impressora.cozinha',
                                                           'USUARIO_UBUNTU;PORTA_DA_IMPRESSORA')
            raise osv.except_osv(('Atencao!'), ('Parametros de sistema da impressora nao configurados!'))
        try:
            parametros = parametros.split(';')
        except:
            raise osv.except_osv(('Atencao!'), ('Parametros de sistema da impressora estao incorretos!'))

        nome = cmd.get('supcci_marca') or ''
        if nome.upper() in ('ELGIN'):
            corta_papel = '\n\n' + corta_papel

        texto = (cmd.get('supcci_espacamento_linha') or '') + texto
        file = open(arquivo, 'w')
        file.write(texto.format(b1=ini_negrito,
                                b2=fim_negrito,
                                s1=ini_sub,
                                s2=fim_sub,
                                f1=fonte_i,
                                f2=fonte_f,
                                corta=corta_papel).decode('string_escape'))
        file.close()
        try:
            if vals_impressora.get('porta') or nome.upper() in ('ELGIN', 'EPSON'):
                os.system("echo %s | sudo -S chmod 776 %s; cat %s > %s" %
                          (parametros[0] or 'sig',
                           vals_impressora.get('porta') or parametros[1],
                           arquivo,
                           vals_impressora.get('porta') or parametros[1]))
            else:
                subprocess.call(["lp", "-o raw", "-n1", '-d%s' % vals_impressora.get('impressora'), arquivo])

        except Exception as e:
            return [0, '%s' % e]

        return [1, "Imprimiu"]
